==> aws_service_catalog_puppet-0.224.0.tar.gz: aws_service_catalog_puppet-0.224.0/servicecatalog_puppet/environmental_variables.py <==
#  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#  SPDX-License-Identifier: Apache-2.0

EXECUTOR_ACCOUNT_ID = "SCT_EXECUTOR_ACCOUNT_ID"
TASK_IDEMPOTENCY_TOKEN = "SCT_TASK_IDEMPOTENCY_TOKEN"
RUN_IDEMPOTENCY_TOKEN = "SCT_RUN_IDEMPOTENCY_TOKEN"
EXECUTION_MODE = "SCT_EXECUTION_MODE"
PUPPET_ACCOUNT_ID = "SCT_PUPPET_ACCOUNT_ID"
SINGLE_ACCOUNT_ID = "SCT_SINGLE_ACCOUNT_ID"
NUM_WORKERS = "SCT_NUM_WORKERS"
SHOULD_DELETE_ROLLBACK_COMPLETE_STACKS = "SCT_SHOULD_DELETE_ROLLBACK_COMPLETE_STACKS"
SHOULD_USE_PRODUCT_PLANS = "SCT_SHOULD_USE_PRODUCT_PLANS"
INITIALISER_STACK_TAGS = "SCT_INITIALISER_STACK_TAGS"
VERSION = "SCT_VERSION"
HOME_REGION = "SCT_HOME_REGION"
REGIONS = "SCT_REGIONS"
SHOULD_USE_SNS = "SCT_SHOULD_USE_SNS"
SHOULD_FORWARD_EVENTS_TO_EVENTBRIDGE = "SCT_SHOULD_FORWARD_EVENTS_TO_EVENTBRIDGE"
SHOULD_FORWARD_FAILURES_TO_OPSCENTER = "SCT_SHOULD_FORWARD_FAILURES_TO_OPSCENTER"
OUTPUT_CACHE_STARTING_POINT = "SCT_OUTPUT_CACHE_STARTING_POINT"
IS_CACHING_ENABLED = "SCT_IS_CACHING_ENABLED"
GLOBAL_SHARING_MODE = "SCT_GLOBAL_SHARING_MODE"
GLOBAL_SHARE_TAG_OPTIONS = "SCT_GLOBAL_SHARE_TAG_OPTIONS"
ON_COMPLETE_URL = "SCT_ON_COMPLETE_URL"
SPOKE_EXECUTION_MODE_DEPLOY_ENV = "SCT_SPOKE_EXECUTION_MODE_DEPLOY_ENV"
SCHEDULER_THREADS_OR_PROCESSES = "SCT_SCHEDULER_THREADS_OR_PROCESSES"
SCHEDULER_ALGORITHM = "SCT_SCHEDULER_ALGORITHM"
SPOKE_SCHEDULER_THREADS_OR_PROCESSES = "SCT_SPOKE_SCHEDULER_THREADS_OR_PROCESSES"
SPOKE_SCHEDULER_ALGORITHM = "SCT_SPOKE_SCHEDULER_ALGORITHM"
GLOBAL_SHARE_PRINCIPALS = "SCT_GLOBAL_SHARE_PRINCIPALS"

==> aws_service_catalog_puppet-0.226.0.tar.gz: aws_service_catalog_puppet-0.226.0/servicecatalog_puppet/environmental_variables.py <==
#  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#  SPDX-License-Identifier: Apache-2.0

EXECUTOR_ACCOUNT_ID = "SCT_EXECUTOR_ACCOUNT_ID"
DRIFT_TOKEN = "SCT_DRIFT_TOKEN"
RUN_TOKEN = "SCT_RUN_TOKEN"
EXECUTION_MODE = "SCT_EXECUTION_MODE"
PUPPET_ACCOUNT_ID = "SCT_PUPPET_ACCOUNT_ID"
SINGLE_ACCOUNT_ID = "SCT_SINGLE_ACCOUNT_ID"
NUM_WORKERS = "SCT_NUM_WORKERS"
SHOULD_DELETE_ROLLBACK_COMPLETE_STACKS = "SCT_SHOULD_DELETE_ROLLBACK_COMPLETE_STACKS"
SHOULD_USE_PRODUCT_PLANS = "SCT_SHOULD_USE_PRODUCT_PLANS"
INITIALISER_STACK_TAGS = "SCT_INITIALISER_STACK_TAGS"
VERSION = "SCT_VERSION"
HOME_REGION = "SCT_HOME_REGION"
REGIONS = "SCT_REGIONS"
SHOULD_USE_SNS = "SCT_SHOULD_USE_SNS"
SHOULD_FORWARD_EVENTS_TO_EVENTBRIDGE = "SCT_SHOULD_FORWARD_EVENTS_TO_EVENTBRIDGE"
SHOULD_FORWARD_FAILURES_TO_OPSCENTER = "SCT_SHOULD_FORWARD_FAILURES_TO_OPSCENTER"
OUTPUT_CACHE_STARTING_POINT = "SCT_OUTPUT_CACHE_STARTING_POINT"
IS_CACHING_ENABLED = "SCT_IS_CACHING_ENABLED"
GLOBAL_SHARING_MODE = "SCT_GLOBAL_SHARING_MODE"
GLOBAL_SHARE_TAG_OPTIONS = "SCT_GLOBAL_SHARE_TAG_OPTIONS"
ON_COMPLETE_URL = "SCT_ON_COMPLETE_URL"
SPOKE_EXECUTION_MODE_DEPLOY_ENV = "SCT_SPOKE_EXECUTION_MODE_DEPLOY_ENV"
SCHEDULER_THREADS_OR_PROCESSES = "SCT_SCHEDULER_THREADS_OR_PROCESSES"
SCHEDULER_ALGORITHM = "SCT_SCHEDULER_ALGORITHM"
SPOKE_SCHEDULER_THREADS_OR_PROCESSES = "SCT_SPOKE_SCHEDULER_THREADS_OR_PROCESSES"
SPOKE_SCHEDULER_ALGORITHM = "SCT_SPOKE_SCHEDULER_ALGORITHM"
GLOBAL_SHARE_PRINCIPALS = "SCT_GLOBAL_SHARE_PRINCIPALS"
